@@ -218,6 +218,9 @@ SERVICE_VERSIONS = {
     "cloudhsm": [
         "2019-11-12"
     ],
+    "cloudmate": [
+        "2025-10-30"
+    ],
     "cloudstudio": [
         "2023-05-08"
     ],
@@ -282,6 +285,9 @@ SERVICE_VERSIONS = {
     "dbdc": [
         "2020-10-29"
     ],
+    "dbs": [
+        "2021-11-08"
+    ],
     "dc": [
         "2018-04-10"
     ],
@@ -543,7 +549,8 @@ SERVICE_VERSIONS = {
         "2021-07-28"
     ],
     "rce": [
-        "2020-11-03"
+        "2020-11-03",
+        "2025-04-25"
     ],
     "redis": [
         "2018-04-12"
@@ -772,6 +779,9 @@ SERVICE_VERSIONS = {
     "weilingwith": [
         "2023-04-27"
     ],
+    "wimgs": [
+        "2025-11-06"
+    ],
     "wsa": [
         "2025-05-08"
     ],
